@@ -29,8 +29,8 @@ import numpy
 from astropy import units
 
 from ...segments import SegmentListDict
-from ...tests import (utils, mocks)
-from ...tests.mocks import mock
+from ...testing import (utils, mocks)
+from ...testing.compat import mock
 from .. import (Channel, ChannelList)
 
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
@@ -71,7 +71,7 @@ OMEGA_CONFIG = """
   plotNormalizedEnergyRange:   [0 25.5]
   alwaysPlotFlag:              0
 }
-"""  # nopep8
+"""
 
 CLF = """
 [group-1]
@@ -87,10 +87,10 @@ fhigh = 60
 qhigh = 60
 frametype = H1_R
 channels =
-	H1:ISI-GND_STS_HAM2_X_DQ 512 safe flat
-	H1:ISI-GND_STS_HAM2_Y_DQ 256 unsafe flat
-	H1:ISI-GND_STS_HAM2_Z_DQ 512 glitchy
-"""  # nopep8
+    H1:ISI-GND_STS_HAM2_X_DQ 512 safe flat
+    H1:ISI-GND_STS_HAM2_Y_DQ 256 unsafe flat
+    H1:ISI-GND_STS_HAM2_Z_DQ 512 glitchy
+"""
 
 
 # -- Channel ------------------------------------------------------------------
@@ -442,13 +442,14 @@ class TestChannelList(object):
 
     @utils.skip_missing_dependency('nds2')
     def test_query_nds2_availability(self):
-        # mock NDS2 query
+        # mock NDS2 connection
         ndsb = mocks.nds2_buffer(self.NAMES[0], [], 0, 64, 'm')
-        availability = [
-            mocks.nds2_availability(self.NAMES[0], [(0, 10), (20, 30)]),
-        ]
         conn = mocks.nds2_connection(buffers=[ndsb])
-        conn.get_availability.return_value = availability
+        # mock availability
+        availability = [mocks.nds2_availability(self.NAMES[0],
+                                                [(0, 10), (20, 30)])]
+        conn.get_availability = lambda x: availability
+
         with mock.patch('nds2.connection') as ndsc:
             ndsc.return_value = conn
 
