@@ -31,8 +31,8 @@ import gwpy.spectrogram
 print("import: 'gwpy.table'")
 import gwpy.table
 
-print("import: 'gwpy.tests'")
-import gwpy.tests
+print("import: 'gwpy.testing'")
+import gwpy.testing
 
 print("import: 'gwpy.time'")
 import gwpy.time
